@@ -8,48 +8,20 @@
  * such preprocess, process, alters, and theme function overrides.
  *
  * Preprocess and process functions are used to modify or create variables for
- * templates and theme functions. They are a common theming tool in Drupal, often
- * used as an alternative to directly editing or adding code to templates. Its
- * worth spending some time to learn more about these functions - they are a
- * powerful way to easily modify the output of any template variable.
+ * templates and theme functions. They are a common theming tool in Drupal,
+ * often used as an alternative to directly editing or adding code to
+ * templates. Its worth spending some time to learn more about these functions -
+ * they are a powerful way to easily modify the output of any template variable.
  *
- * Preprocess and Process Functions SEE: http://drupal.org/node/254940#variables-processor
- * 1. Rename each function and instance of "sitebuilder_uvt" to match
- *    your subthemes name, e.g. if your theme name is "footheme" then the function
- *    name will be "footheme_preprocess_hook". Tip - you can search/replace
- *    on "sitebuilder_uvt".
+ * Preprocess and Process Functions SEE:
+ * http://drupal.org/node/254940#variables-processor
+ * 1. Rename each function and instance of "sitebuilder_uvt" to match your
+ *    subthemes name, e.g. if your theme name is "footheme" then the function
+ *    name will be "footheme_preprocess_hook". Tip - you can search/replace on
+ *    "sitebuilder_uvt".
  * 2. Uncomment the required function to use.
  */
 
-
-/**
- * Preprocess variables for the html template.
- */
-/* -- Delete this line to enable.
-function sitebuilder_uvt_preprocess_html(&$vars) {
-  global $theme_key;
-
-  // Two examples of adding custom classes to the body.
-
-  // Add a body class for the active theme name.
-  // $vars['classes_array'][] = drupal_html_class($theme_key);
-
-  // Browser/platform sniff - adds body classes such as ipad, webkit, chrome etc.
-  // $vars['classes_array'][] = css_browser_selector();
-
-}
-// */
-
-
-/**
- * Process variables for the html template.
- */
-/* -- Delete this line if you want to use this function
-function sitebuilder_uvt_process_html(&$vars) {
-}
-// */
-
-
 /**
  * Override or insert variables for the page templates.
  */
@@ -58,39 +30,6 @@ function sitebuilder_uvt_preprocess_page(&$vars) {
   // requires the Browscap module and returns TRUE or FALSE.
 }
 
-
-/**
- * Override or insert variables into the node templates.
- */
-/* -- Delete this line if you want to use these functions
-function sitebuilder_uvt_preprocess_node(&$vars) {
-}
-function sitebuilder_uvt_process_node(&$vars) {
-}
-// */
-
-
-/**
- * Override or insert variables into the comment templates.
- */
-/* -- Delete this line if you want to use these functions
-function sitebuilder_uvt_preprocess_comment(&$vars) {
-}
-function sitebuilder_uvt_process_comment(&$vars) {
-}
-// */
-
-
-/**
- * Override or insert variables into the block templates.
- */
-/* -- Delete this line if you want to use these functions
-function sitebuilder_uvt_preprocess_block(&$vars) {
-}
-function sitebuilder_uvt_process_block(&$vars) {
-}
-// */
-
 /**
  * Shows listing of asset metadata.
  *
@@ -107,12 +46,22 @@ function sitebuilder_uvt_mediamosa_ck_views_theme_asset_metadata($variables) {
   ksort($variables['metadata']);
 
   foreach ($variables['metadata'] as $name => $value) {
+    if ($name == 'source') {
+      $name = t('Retention period');
+    }
+    if (($name == 'created') and (isset($value)) and (substr($value, -9) == ' 00:00:00')) {
+      $value = substr($value, 0, -9);
+    }
     $name = drupal_ucfirst(str_replace('_', ' ', $name));
     if (empty($value)) {
-      $rows[] = array('class' => array('empty'), 'data' => array('name' => t($name), 'value' => ''));
+      $rows[] = array(
+        'class' => array('empty'), 'data' => array('name' => $name, 'value' => ''),
+      );
     }
     else {
-      $rows[] = array('data' => array('name' => t($name), 'value' => nl2br(check_plain(t($value)))));
+      $rows[] = array(
+        'data' => array('name' => $name, 'value' => nl2br(check_plain($value))),
+      );
     }
   }
   if (empty($rows)) {
